@@ -1,7 +1,8 @@
 /*
  * calc - arbitrary precision calculator
  *
- * Copyright (C) 1999-2013  David I. Bell, Landon Curt Noll and Ernest Bowen
+ * Copyright (C) 1999-2013,2021  David I. Bell, Landon Curt Noll
+ *				 and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -403,7 +404,7 @@ main(int argc, char **argv)
 								" long");
 							exit(18);
 						}
-						/* XXX What if *cp = '\''? */
+						/* XXX - what if *cp = '\''? */
 						*bp++ = '\'';
 						strncpy(bp, cp, len+1);
 						bp += len;
@@ -479,7 +480,22 @@ main(int argc, char **argv)
 				program);
 			exit(21);
 		}
-		strncpy(cmdbuf + cmdlen, cp, cplen+1);
+		/*
+		 * The next statement could be:
+		 *
+		 *	strncpy(cmdbuf + cmdlen, cp, cplen);
+		 *
+		 * however compilers like gcc would issue warnings such as:
+		 *
+		 * 	specified bound depends on the length of the
+		 * 	source argument
+		 *
+		 * even though we terminate the string by setting a NUL
+		 * byte following the copy.  Therefore we call memcpy()
+		 * instead to avoid such warnings.
+		 */
+		memcpy(cmdbuf + cmdlen, cp, cplen);
+		cmdbuf[newcmdlen] = '\0';
 		cmdlen = newcmdlen;
 		index++;
 		if (index < maxindex)
