@@ -1,7 +1,7 @@
 /*
  * codegen - module to generate opcodes from the input tokens
  *
- * Copyright (C) 1999-2007,2017  David I. Bell and Ernest Bowen
+ * Copyright (C) 1999-2007,2017,2021  David I. Bell and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -2607,7 +2607,7 @@ getid(char *buf)
  * global or if symtype is static and the old variable is at the same
  * level.  Warnings are issued when a global or local variable is
  * redeclared and when in the same body the variable will be accessible only
- ^ with the appropriate specfier.
+ ^ with the appropriate specifier.
  */
 S_FUNC void
 definesymbol(char *name, int symtype)
