@@ -1,7 +1,7 @@
 /*
  * file - file I/O routines callable by users
  *
- * Copyright (C) 1999-2007,2018  David I. Bell and Landon Curt Noll
+ * Copyright (C) 1999-2007,2018,2021  David I. Bell and Landon Curt Noll
  *
  * Primary author:  David I. Bell
  *
@@ -50,6 +50,8 @@
 
 #define READSIZE	1024	/* buffer size for reading */
 
+#define MIN(a,b) (((a) <= (b)) ? (a) : (b))
+
 /*
  * external STDIO functions
  */
@@ -97,7 +99,7 @@ S_FUNC void fskipnum(FILE *fp);
 
 
 /*
- * file_init - perform needed initilization work
+ * file_init - perform needed initialization work
  *
  * On some systems, one cannot initialize a pointer to a FILE *.
  * This routine, called once at startup is a work-a-round for
@@ -238,7 +240,7 @@ init_fileio(FILEIO *fiop, char *name, char *mode,
 	 * determine file open mode
 	 *
 	 * While a leading 'r' is for reading and a leading 'w' is
-	 * for writing, the presense of a '+' in the string means
+	 * for writing, the presence of a '+' in the string means
 	 * both reading and writing.  A leading 'a' means append
 	 * which is writing.
 	 */
@@ -1406,7 +1408,7 @@ z2filepos(ZVALUE zpos)
 	/*
 	 * firewall
 	 */
-	zpos.sign = 0;	/* deal only with the absolue value */
+	zpos.sign = 0;	/* deal only with the absolute value */
 
 	/*
 	 * quick return if the position can fit into a long
@@ -1414,23 +1416,22 @@ z2filepos(ZVALUE zpos)
 #if FILEPOS_BITS == FULL_BITS
 	/* ztofull puts the value into native byte order */
 	pos = ztofull(zpos);
-	/* on some hosts, FILEPOS is not a scalar */
-	memset(&ret, 0, sizeof(FILEPOS));
-	memcpy((void *)&ret, (void *)&pos, sizeof(FILEPOS));
+	memset(&ret, 0, sizeof(ret));	/* FILEPOS could be non-scalar */
+	memcpy((void *)&ret, (void *)&pos, MIN(sizeof(ret), sizeof(pos)));
 	return ret;
 #elif FILEPOS_BITS < FULL_BITS
 	/* ztofull puts the value into native byte order */
 	pos = ztolong(zpos);
-	/* on some hosts, FILEPOS is not a scalar */
-	memset(&ret, 0, sizeof(FILEPOS));
-	memcpy((void *)&ret, (void *)&pos, sizeof(pos));
+	memset(&ret, 0, sizeof(ret));	/* FILEPOS could be non-scalar */
+	memcpy((void *)&ret, (void *)&pos, MIN(sizeof(ret), sizeof(pos)));
 	return ret;
 #else /* FILEPOS_BITS > FULL_BITS */
 	if (!zgtmaxfull(zpos)) {
 		/* ztofull puts the value into native byte order */
 		pos = ztofull(zpos);
-		memset(&ret, 0, sizeof(FILEPOS));
-		memcpy((void *)&ret, (void *)&pos, sizeof(pos));
+		memset(&ret, 0, sizeof(ret)); /* FILEPOS could be non-scalar */
+		memcpy((void *)&ret, (void *)&pos,
+				     MIN(sizeof(ret), sizeof(pos)));
 		return ret;
 	}
 
@@ -1439,11 +1440,13 @@ z2filepos(ZVALUE zpos)
 	 */
 	if (zpos.len >= FILEPOS_BITS/BASEB) {
 		/* copy the lower FILEPOS_BITS of the ZVALUE */
-		memcpy(&tmp, zpos.v, sizeof(FILEPOS));
+		memset(&tmp, 0, sizeof(tmp)); /* FILEPOS could be non-scalar */
+		memcpy(&tmp, zpos.v, MIN(sizeof(tmp), FILEPOS_LEN);
 	} else {
 		/* copy what bits we can into the temp value */
-		memset(&tmp, 0, sizeof(FILEPOS));
-		memcpy(&tmp, zpos.v, zpos.len*BASEB/8);
+		memset(&tmp, 0, sizeof(tmp)); /* FILEPOS could be non-scalar */
+		memcpy(&tmp, zpos.v, MIN(sizeof(tmp),
+			     MIN(zpos.len*BASEB/8, FILEPOS_LEN)));
 	}
 	/* swap into native byte order */
 	SWAP_HALF_IN_FILEPOS(&ret, &tmp);
@@ -1646,7 +1649,7 @@ set_open_pos(FILE *fp, ZVALUE zpos)
 	}
 
 	/*
-	 * return sucess
+	 * return success
 	 */
 	return 0;
 }
@@ -2603,7 +2606,7 @@ isattyid(FILEID id)
  * given:
  *	id	FILEID to search
  *	str	string to look for
- *	pos	file postion to start at (NULL => current position)
+ *	pos	file position to start at (NULL => current position)
  *
  * returns:
  *	EOF if system error
@@ -2613,7 +2616,7 @@ isattyid(FILEID id)
  *
  * XXX - This search is a translation of the original search that did not
  *	 work with large files.	 The search algorithm used is slow and
- *	 should be spead up much more.
+ *	 should be speed up much more.
  */
 int
 fsearch(FILEID id, char *str, ZVALUE start, ZVALUE end, ZVALUE *res)
