@@ -1,7 +1,7 @@
 /*
  * hist - interactive readline module
  *
- * Copyright (C) 1999-2007  David I. Bell
+ * Copyright (C) 1999-2007,2021  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -403,7 +403,7 @@ hist_term(void)
 	hist_last = NULL;
 
 	/*
-	 * restore orignal tty state
+	 * restore original tty state
 	 */
 	(void) orig_tty(STDIN);
 }
@@ -745,10 +745,20 @@ hist_saveline(char *line, int len)
 	 * Add the line to the end of the history table.
 	 */
 	hp = malloc(sizeof(HIST));
+	if (hp == NULL) {
+		fprintf(stderr,
+			"Out of memory adding line to the history table #0\n");
+		return;
+	}
 	hp->next = NULL;
 	hp->prev = NULL;
 	hp->len = len;
 	hp->data = malloc(len);
+	if (hp->data == NULL) {
+		fprintf(stderr,
+			"Out of memory adding line to the history table #1\n");
+		return;
+	}
 	memcpy(hp->data, line, len);
 	HS.curhist = ++HS.histcount;
 	if (!hist_first)
