@@ -59,6 +59,10 @@ initstr(STRINGHEAD *hp)
 {
 	if (hp->h_list == NULL) {
 		hp->h_list = (char *)malloc(2000);
+		if (hp->h_list == NULL) {
+			math_error("Cannot allocate string header");
+			/*NOTREACHED*/
+		}
 		hp->h_avail = 2000;
 		hp->h_used = 0;
 	}
@@ -74,7 +78,7 @@ initstr(STRINGHEAD *hp)
  * Copy a string to the end of a list of strings, and return the address
  * of the copied string.  Returns NULL if the string could not be copied.
  * No checks are made to see if the string is already in the list.
- * The string cannot be null or have imbedded nulls.
+ * The string cannot be null or have embedded nulls.
  *
  * given:
  *	hp		header of string storage
@@ -1226,7 +1230,7 @@ STRING *
 slink(STRING *s)
 {
 	if (s->s_links <= 0) {
-		math_error("Argument for slink has nonpositive links!!!");
+		math_error("Argument for slink has non-positive links!!!");
 		/*NOTREACHED*/
 	}
 	++s->s_links;
@@ -1238,7 +1242,7 @@ void
 sfree(STRING *s)
 {
 	if (s->s_links <= 0) {
-		math_error("Argument for sfree has nonpositive links!!!");
+		math_error("Argument for sfree has non-positive links!!!");
 		/*NOTREACHED*/
 	}
 	if (--s->s_links > 0 || s->s_len == 0)
