@@ -44,8 +44,8 @@ static char *program;
 
 #define MAJOR_VER	2	/* major library version */
 #define MINOR_VER	12	/* minor library version */
-#define MAJOR_PATCH	7	/* major software level under library version */
-#define MINOR_PATCH	6	/* minor software level or 0 if not patched */
+#define MAJOR_PATCH	8	/* major software version level */
+#define MINOR_PATCH	2	/* minor software version level */
 
 
 /*
@@ -131,8 +131,22 @@ version(void)
 		fprintf(stderr, "%s: cannot malloc version string\n", program);
 		exit(70);
 	}
-	strncpy(stored_version, verbuf, len);
-	stored_version[len] = '\0';	/* paranoia */
+	/*
+	 * The next statement could be:
+	 *
+	 *	strncpy(stored_version, verbuf, len);
+	 *
+	 * however compilers like gcc would issue warnings such as:
+	 *
+	 * 	specified bound depends on the length of the
+	 * 	source argument
+	 *
+	 * even though we terminate the string by setting a NUL
+	 * byte following the copy.  Therefore we call memcpy()
+	 * instead to avoid such warnings.
+	 */
+	memcpy(stored_version, verbuf, len);
+	stored_version[len] = '\0';
 
 	/*
 	 * return the newly malloced buffer
